@@ -7,7 +7,7 @@ mod ping;
 use std::net::IpAddr;
 
 pub use client::Client;
-pub use config::Config;
+pub use config::{Config, ConfigBuilder};
 pub use error::SurgeError;
 pub use icmp::{icmpv4::Icmpv4Packet, icmpv6::Icmpv6Packet, IcmpPacket};
 pub use ping::Pinger;
@@ -46,7 +46,7 @@ pub async fn pinger(host: IpAddr) -> Result<Pinger, SurgeError> {
         IpAddr::V4(_) => Config::default(),
         IpAddr::V6(_) => Config::builder().kind(ICMP::V6).build(),
     };
-    let client = Client::new(&config)?;
+    let client = Client::new(&config).await?;
     let pinger = client.pinger(host).await;
     Ok(pinger)
 }
